/* drivers/barcelona/gprs/faro.c
 *
 * GPRS driver for Foxlink FARO
 *
 * Copyright (C) 2007 TomTom BV <http://www.tomtom.com/>
 * Author: Jaap-Jan Boor <jaap-jan.boor@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include <linux/delay.h>
#include <barcelona/gopins.h>
#include <barcelona/gotype.h>
#include "gprs.h"

int faro_detect(struct gprs_modem *device)
{
	int rc;

	rc = ((IO_GetModelId() == GOTYPE_CAGLIARI) || (IO_GetModelId() == GOTYPE_FLORENCE)) && (IO_HaveGprsModem());
	if (rc)
		device->stat = GPRS_STATUS_OFF;

	return rc;
}

#ifdef CONFIG_PM
int faro_suspend(struct gprs_modem *device)
{
	return 0;
}

int faro_resume(struct gprs_modem *device)
{
	return 0;
}
#endif

int faro_reset(struct gprs_modem *device)
{
	if (device->stat == GPRS_STATUS_ON) {
		IO_Deactivate(GSM_SYS_RST);
		msleep(1);
		IO_Activate(GSM_SYS_RST);
		msleep(1);
		IO_Deactivate(GSM_SYS_RST);

		return 0;
	} else
		return -1;
}

int faro_off(struct gprs_modem *device)
{
	if (device->stat == GPRS_STATUS_ON) {
		printk("GPRS: %s NOT IMPLEMENTED, use AT commands\n",
		       __func__);
		device->stat = GPRS_STATUS_OFF;
		return 0;
	} else
		return -1;
}

int faro_on(struct gprs_modem *device)
{
	/* start with a reset, we don't know the state the modem was left in */
	IO_Deactivate(GSM_SYS_RST);
	msleep(1);
	IO_Activate(GSM_SYS_RST);
	msleep(1);
	IO_Deactivate(GSM_SYS_RST);

	/* power on sequence */
	IO_Deactivate(GSM_SYS_EN);
	msleep(20);
	IO_Activate(GSM_SYS_EN);
	msleep(2000);
	IO_Deactivate(GSM_SYS_EN);
	msleep(1200);

	IO_SetFunction(GSM_RXD);
	IO_SetFunction(GSM_TXD);
	IO_SetFunction(GSM_RTS);
	IO_SetFunction(GSM_CTS);

	device->stat = GPRS_STATUS_ON;

	return 0;
}
